---
sphinx:
  config:
  html_theme_options:
    {
      "search_bar_text": "Search this site...",
      "launch_buttons":
      {
        "notebook_interface": "jupyterlab",
        "binderhub_url": "",
        "jupyterhub_url": "http://bitzer.cs.williams.edu",
        "thebe": False,
        "colab_url": "",
      },
      "path_to_docs": "",
      "repository_url": "https://github.com/stephenfreund/cs134-lectures",
      "repository_branch": "main",
      "google_analytics_id": "",
      "extra_navbar": "",
      "extra_footer": "",
      "home_page_in_toc": True,
      "use_download_button": False,
      "use_repository_button": False,
      "use_edit_page_button": False,
      "use_issues_button": False,
    }
---
# Style Examples

These examples illustrate some style suggestions to help you write beautiful code.  Our [](../../docs/style-guide.md) has a much
more detailed discussion of style.

<style type="text/css" rel="stylesheet">
  pre { 
      background: white;
      margin: 0;
      border: 0;
      box-shadow: none;
  }

  .admonition code {
      color: rgba(var(--pst-color-paragraph),1);
  }

  .admonition p.admonition-title~* {
      padding: 0; 
  }

  h2 {
      font-size: var(--pst-font-size-h3);
  }
  h3 {
      font-size: var(--pst-font-size-h4);
  }
}
</style>


## Simplify Ifs returning Boolean Values


`````{panels}
:body: p-0 m-0
:card: border-0
:column: col-6 p-0 pr-2
````{admonition} Don't
:class: danger p-0 m-0
```
def isEven(x):
  if x % 2 == 0:
      return True
  else:
      return False
```
````
---
````{admonition} Do
:class: tip p-0 m-0
```
def isEven(x):
  return x % 2 == 0
```
````
`````

## Avoid Using == to Compare to True 


`````{panels}
:body: p-0 m-0
:card: border-0
:column: col-6 p-0 pr-2
````{admonition} Don't
:class: danger p-0 m-0
```
if isEven(10) == True:
  print("Yes")
else:
  print("No")      
```
````
---
````{admonition} Do
:class: tip p-0 m-0
```
if isEven(10):
  print("Yes")
else:
  print("No")
```
````
`````

## Use And Instead of Nested Ifs When Appropriate


`````{panels}
:body: p-0 m-0
:card: border-0
:column: col-6 p-0 pr-2
````{admonition} Don't
:class: danger p-0 m-0
```
if isEven(x):
  if isEven(y):
      print("Yes")
```
````
---
````{admonition} Do
:class: tip p-0 m-0
```
if isEven(x) and isEven(y):
  print("Yes")
```
````
`````

## Use Descriptive Names and Consistent Capitalization

`````{panels}
:body: p-0 m-0
:card: border-0
:column: col-6 p-0 pr-2
````{admonition} Don't
:class: danger p-0 m-0
```
def longWords(x):
  r = []
  for item1 in x:
      if len(item1) > 12:
        r.append(item1)
  return r
```
````
---
````{admonition} Do
:class: tip p-0 m-0
```
def longWords(dictonary):
  wordsFound = []
  for word in dictionary
      if len(word) > 12:
        wordsFound.append(word)
  return wordsFound
```
````
`````

## Comments Should Complement What the Code Says

`````{panels}
:body: p-0 m-0
:card: border-0
:column: col-6 p-0 pr-2
````{admonition} Don't
:class: danger p-0 m-0
```
def longWords(dictionary):
  # make an empty list
  wordsFound = []
  
  # iterate over all the words
  for word in dictionary:
      
      # test if length of the word is > 12
      if len(word) > 12:
        
        # if so, add the word to wordsFound
        wordsFound.append(word)
        
  # return result
  return wordsFound
```
````
---
````{admonition} Do
:class: tip p-0 m-0
```
def longWords(dictionary):
  """
  Return a list of all words in dictionary
  13 or more characters.
  """

  # Iterate over all words in the dictionary,
  #  adding the long ones to wordsFound.
  wordsFound = []
  for word in dictionary:
      if len(word) > 12:
        result.wordsFound(word)
        
  return wordsFound
```
````
`````


## Remove Old or Incorrect Comments From Code

`````{panels}
:body: p-0 m-0
:card: border-0
:column: col-6 p-0 pr-2
````{admonition} Don't
:class: danger p-0 m-0
```
def cube(n):
  """Compute n^3"""
  
  # Fill in this method
  # Compute n^2
  return n * n * n
  # pass
```
````
---
````{admonition} Do
:class: tip p-0 m-0
```
def cube(n):
  """Compute n^3"""

  return n * n * n
```
````
`````


## Limit Lines to About 80 Characters Wide

(Atom has a feint white vertical line to help you keep to a reasonable width)

`````{panels}
:body: p-0 m-0
:card: border-0
:column: col-6 p-0 pr-2
````{admonition} Don't
:class: danger p-0 m-0
```
def cube(n):
  """Compute n^3"""
  # This is a super long comment that just goes on and on and on and on and on and on and on and on and on and on and on and on and on and on and on and on and on and on and on and on and on and on and on and on and on 
  return n * n * n
```
````
---
````{admonition} Do
:class: tip p-0 m-0
```
def cube(n):
  """Compute n^3"""
  # This is a super long comment that just 
  # goes on and on and on and on and on and 
  # on and on and on and on and on and on ...
  # (This is even narrower than 80 chars so
  # it looks nice on the web :)
  return n * n * n
```
````
`````



## Fix Broken Doc Tests

(Atom has a feint white vertical line to help you keep to a reasonable width)

`````{panels}
:body: p-0 m-0
:card: border-0
:column: col-6 p-0 pr-2
````{admonition} Don't
:class: danger p-0 m-0
```
def cube(n):
  """
  Compute n^3.
  >>> cube(3)
  9
  """
  return n * n * n
```
````
---
````{admonition} Do
:class: tip p-0 m-0
```
def cube(n):
  """
  Compute n^3.
  >>> cube(3)
  27
  """
  return n * n * n
```
````
`````
